﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="ChangedOption.cs" company="HandBrake Project (http://handbrake.fr)">
// This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
// </copyright>
// --------------------------------------------------------------------------------------------------------------------

namespace HandBrakeWPF.Model
{
    public enum ChangedOption
    {
        None,
        Quality,
        Bitrate,
        Encoder,
        Chapters,
        Dimensions
    }
}
